@@ -104,6 +104,7 @@ class ScriptLibInfo
 	// Magic3管理画面専用jQueryプラグイン
 	const LIB_JQUERY_M3_SLIDEPANEL		= 'jquery.m3slidepanel';		// スライドパネル
 	const LIB_JQUERY_M3_DROPDOWN		= 'jquery.m3dropdown';		// ドロップダウンメニュー
+	const LIB_JQUERY_M3_STICKHEADER		= 'jquery.m3stickyheader';		// スクロールバー付きテーブル
 	
 	// CodeMirror
 	const LIB_CODEMIRROR_JAVASCRIPT	= 'codemirror.javascript';		// CodeMirror Javascript
@@ -119,9 +120,6 @@ class ScriptLibInfo
 	const JQUERY_QTIP_VER			= '1.0';
 	const JQUERY_QTIP2_VER			= '2.1.1';
 	const JQUERY_CALCULATION_VER	= '0.4.07';
-	//const JQUERY_JQPLOT_VER			= '0.9.7';
-//const JQUERY_JQPLOT_VER			= '1.0.4r1120';
-//	const JQUERY_JQPLOT_VER			= '1.0.7';
 	const JQUERY_JQPLOT_VER			= '1.0.8';
 	const JQUERY_JSTREE_VER			= '1.0-rc3';
 	const JQUERY_IFRAME_VER			= '2.0.0';
@@ -146,9 +144,6 @@ class ScriptLibInfo
 	const CODEMIRROR_VER			= '3.1';
 	
 	// ライブラリディレクトリ
-	//const JQUERY_JQPLOT_DIR			= 'jquery/jqplot';
-//	const JQUERY_JQPLOT_DIR			= 'jquery/jqplot1.0';
-//	const JQUERY_JQPLOT_DIR			= 'jquery/jqplot1.0.7';
 	const JQUERY_JQPLOT_DIR			= 'jquery/jqplot1.0.8';
 	
 	// jQuery UI
@@ -200,15 +195,8 @@ class ScriptLibInfo
 	const JQUERY_QTIP2_FILENAME			= 'jquery/qtip2-2.1.1/jquery.qtip.min.js';
 	const JQUERY_QTIP2_CSS				= 'jquery/qtip2-2.1.1/jquery.qtip.min.css';
 	const JQUERY_CALCULATION_FILENAME	= 'jquery/jquery.calculation.js';
-	//const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot/jquery.jqplot.min.js';
-//const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot1.0/jquery.jqplot.min.js';
-//const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot1.0.7/jquery.jqplot.min.js';
-const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot1.0.8/jquery.jqplot.min.js';
-//	const JQUERY_JQPLOT_EX_FILENAME		= 'jquery/jqplot/excanvas.min.js';
-	//const JQUERY_JQPLOT_CSS				= 'jquery/jqplot/jquery.jqplot.css';
-//const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0/jquery.jqplot.min.css';
-//const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.7/jquery.jqplot.min.css';
-const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
+	const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot1.0.8/jquery.jqplot.min.js';
+	const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 	const JQUERY_YOUTUBEPLAYER_FILENAME	= 'jquery/jquery.youtube.player.js';
 	const JQUERY_JSTREE_FILENAME		= 'jquery/jstree/jquery.jstree.js';
 //	const JQUERY_IFRAME_FILENAME		= 'jquery/jquery.iframe-auto-height.plugin.1.5.0.min.js';
@@ -246,6 +234,8 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 	const JQUERY_M3_SLIDEPANEL_FILENAME	= 'jquery/jquery.m3slidepanel.js';	// スライドパネル
 	const JQUERY_M3_DROPDOWN_FILENAME	= 'jquery/jquery.m3dropdown.js';	// ドロップダウンメニュー
 	const JQUERY_M3_DROPDOWN_CSS		= 'jquery/jquery.m3dropdown.css';	// ドロップダウンメニュー
+	const JQUERY_M3_STICKHEADER_FILENAME		= 'jquery/jquery.m3stickyheader.js';	// スクロールバー付きテーブル
+	const JQUERY_M3_STICKHEADER_OTHER_FILENAME	= 'jquery/jquery.ba-throttle-debounce.min.js';	// スクロールバー付きテーブル用ライブラリ
 	
 	// ライブラリの公式サイトのURL
 	const BOOTSTRAP_DATETIMEPICKER_URL	= 'https://github.com/Eonasdan/bootstrap-datetimepicker';
@@ -595,7 +585,8 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 						// Magic3管理画面専用jQueryプラグイン
 						self::LIB_JQUERY_M3_SLIDEPANEL	=>	array(	'script' 	=> array(self::JQUERY_M3_SLIDEPANEL_FILENAME)),	// スライドパネル
 						self::LIB_JQUERY_M3_DROPDOWN	=>	array(	'script' 	=> array(self::JQUERY_M3_DROPDOWN_FILENAME),	// ドロップダウンメニュー
-																	'css'		=> array(self::JQUERY_M3_DROPDOWN_CSS)),
+																	'css'		=> array(self::JQUERY_M3_DROPDOWN_CSS)),												
+						self::LIB_JQUERY_M3_STICKHEADER	=>	array(	'script' 	=> array(self::JQUERY_M3_STICKHEADER_OTHER_FILENAME, self::JQUERY_M3_STICKHEADER_FILENAME)),	// スクロールバー付きテーブル
 																
 						// その他ライブラリ
 						self::LIB_CODEMIRROR_JAVASCRIPT		=>	array(	'script' 	=> array(self::CODEMIRROR_FILENAME, self::CODEMIRROR_JAVASCRIPT_FILENAME),	// CodeMirror用のファイル
