@@ -337,6 +337,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			$html2 = '';
 		}
 		$desc = $request->trimValueOf('item_desc');		// 簡易説明
+		$metaDesc = $request->trimValueOf('item_meta_desc');			// ページ要約
+		$metaKeyword = $request->trimValueOf('item_meta_keyword');	// ページキーワード
 		$status = $request->trimValueOf('item_status');		// エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
 		$category = '';									// カテゴリー
 		$showComment = ($request->trimValueOf('show_comment') == 'on') ? 1 : 0;				// コメントを表示するかどうか
@@ -461,6 +463,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
+										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
+										'be_meta_keywords'		=> $metaKeyword,		// ページキーワード(METAタグ)
 										'be_thumb_filename'		=> $thumbFilename,		// サムネールファイル名
 										'be_related_content'	=> $relatedContent,		// 関連コンテンツ
 										'be_option_fields'		=> $this->serializeArray($this->fieldValueArray));				// ユーザ定義フィールド値
@@ -583,6 +587,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
+										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
+										'be_meta_keywords'		=> $metaKeyword,		// ページキーワード(METAタグ)
 										'be_thumb_filename'		=> $thumbFilename,		// サムネールファイル名
 										'be_related_content'	=> $relatedContent,		// 関連コンテンツ
 										'be_option_fields'		=> $this->serializeArray($this->fieldValueArray));				// ユーザ定義フィールド値
@@ -786,6 +792,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				$html2 = $row['be_html_ext'];				// HTML
 				$html2 = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->getUrl($this->gEnv->getRootUrl()), $html2);// アプリケーションルートを変換
 				$desc = $row['be_description'];		// 簡易説明
+				$metaDesc = $row['be_meta_description'];		// ページ要約(METAタグ)
+				$metaKeyword = $row['be_meta_keywords'];		// ページキーワード(METAタグ)
 				$status = $row['be_status'];				// エントリー状況
 				$reg_user = $row['reg_user_name'];				// 投稿者
 				$entry_date = $this->timestampToDate($row['be_regist_dt']);		// 投稿日
@@ -839,6 +847,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				$html = '';				// HTML
 				$html2 = '';				// HTML
 				$desc = '';		// 簡易説明
+				$metaDesc = '';		// ページ要約(METAタグ)
+				$metaKeyword = '';		// ページキーワード(METAタグ)
 				$status = 0;				// エントリー状況
 				$reg_user = '';				// 投稿者
 				$entry_date = date("Y/m/d");		// 投稿日
@@ -908,6 +918,8 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "item_html", $html);		// HTML
 		$this->tmpl->addVar("_widget", "item_html2", $html2);		// HTML(続き)
 		$this->tmpl->addVar("_widget", "desc", $desc);		// 簡易説明
+		$this->tmpl->addVar("_widget", "meta_desc", $this->convertToDispString($metaDesc));		// ページ要約(METAタグ)
+		$this->tmpl->addVar("_widget", "meta_keyword", $this->convertToDispString($metaKeyword));		// ページキーワード(METAタグ)
 		switch ($status){
 			case 1:	$this->tmpl->addVar("_widget", "selected_edit", 'selected');	break;
 			case 2:	$this->tmpl->addVar("_widget", "selected_public", 'selected');	break;
@@ -1004,8 +1016,9 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 	 */
 	function itemListLoop($index, $fetchedRow, $param)
 	{
-		// シリアル番号
+		// レコード値取得
 		$serial = $fetchedRow['be_serial'];
+		$id		= $fetchedRow['be_id'];
 
 		// カテゴリーを取得
 		$categoryArray = array();
@@ -1027,8 +1040,11 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			case 2:	$status = '<font color="green">公開</font>';	break;
 			case 3:	$status = '非公開';	break;
 		}
-		// 総参照数
-		$totalViewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $serial);
+		// 参照数
+		$updateViewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $serial);		// 更新後からの参照数
+		$totalViewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, 0, $id);		// 新規作成からの参照数
+		$viewCountStr = $updateViewCount;
+		if ($totalViewCount > $updateViewCount) $viewCountStr .= '(' . $totalViewCount . ')';		// 新規作成からの参照数がない旧仕様に対応
 		
 		// ユーザからの参照状況
 		$now = date("Y/m/d H:i:s");	// 現在日時
@@ -1060,14 +1076,15 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 			'index' => $index,		// 項目番号
 			'no' => $index + 1,													// 行番号
 			'serial' => $serial,			// シリアル番号
-			'id' => $this->convertToDispString($fetchedRow['be_id']),			// ID
+			'id' => $this->convertToDispString($id),			// 記事ID
 			'name' => $this->convertToDispString($fetchedRow['be_name']),		// 名前
 			'lang' => $lang,													// 対応言語
 			'eyecatch_image' => $eyecatchImageTag,									// アイキャッチ画像
 			'status_img' => $statusImg,												// 公開状態
 			'status' => $status,													// 公開状況
 			'category' => $category,											// 記事カテゴリー
-			'view_count' => $totalViewCount,									// 総参照数
+			//'view_count' => $totalViewCount,									// 参照数
+			'view_count' => $this->convertToDispString($viewCountStr),			// 参照数
 			'reg_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 投稿者
 			'reg_date' => $this->convertToDispDateTime($fetchedRow['be_regist_dt'], 0/*ロングフォーマット*/, 10/*時分*/)		// 投稿日時
 		);
